# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.168
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_app_aws_delegation_config import AppAppAWSDelegationConfig

class TestAppAppAWSDelegationConfig(unittest.TestCase):
    """AppAppAWSDelegationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppAppAWSDelegationConfig:
        """Test AppAppAWSDelegationConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppAppAWSDelegationConfig`
        """
        model = AppAppAWSDelegationConfig()
        if include_optional:
            return AppAppAWSDelegationConfig(
                access_key_id = '',
                app_sandbox_config_id = '',
                created_at = '',
                created_by = nuon.models.app/account.app.Account(
                    account_type = 'auth0', 
                    created_at = '', 
                    email = '', 
                    id = '', 
                    org_ids = [
                        ''
                        ], 
                    permissions = {
                        'key' : 'unknown'
                        }, 
                    roles = [
                        nuon.models.app/role.app.Role(
                            created_by = nuon.models.app/account.app.Account(
                                created_at = '', 
                                email = '', 
                                id = '', 
                                subject = '', 
                                updated_at = '', ), 
                            created_at = '', 
                            created_by_id = '', 
                            id = '', 
                            policies = [
                                nuon.models.app/policy.app.Policy(
                                    created_at = '', 
                                    created_by = , 
                                    created_by_id = '', 
                                    id = '', 
                                    name = 'org_admin', 
                                    role_id = '', 
                                    updated_at = '', )
                                ], 
                            role_type = 'org_admin', 
                            updated_at = '', )
                        ], 
                    subject = '', 
                    updated_at = '', ),
                created_by_id = '',
                iam_role_arn = '',
                id = '',
                org_id = '',
                secret_access_key = '',
                updated_at = ''
            )
        else:
            return AppAppAWSDelegationConfig(
        )
        """

    def testAppAppAWSDelegationConfig(self):
        """Test AppAppAWSDelegationConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
