# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.87
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.service_create_install_request_azure_account import ServiceCreateInstallRequestAzureAccount

class TestServiceCreateInstallRequestAzureAccount(unittest.TestCase):
    """ServiceCreateInstallRequestAzureAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ServiceCreateInstallRequestAzureAccount:
        """Test ServiceCreateInstallRequestAzureAccount
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ServiceCreateInstallRequestAzureAccount`
        """
        model = ServiceCreateInstallRequestAzureAccount()
        if include_optional:
            return ServiceCreateInstallRequestAzureAccount(
                location = '',
                service_principal_app_id = '',
                service_principal_password = '',
                subscription_id = '',
                subscription_tenant_id = ''
            )
        else:
            return ServiceCreateInstallRequestAzureAccount(
        )
        """

    def testServiceCreateInstallRequestAzureAccount(self):
        """Test ServiceCreateInstallRequestAzureAccount"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
